@@ -181,6 +181,13 @@ class UserObject(object):
 
 ### Squeak & Morphic classes ###
 class BaseMorph(UserObject):
+    """Base Morph.
+
+    bounds are (left, top, right, bottom)
+    right = left + width
+    bottom = top + height
+
+    """
     _fields = ("bounds", "owner", "submorphs", "color", "flags", "properties")
 
     def set_defaults(self):
@@ -218,6 +225,8 @@ class StringMorph(BaseMorph):
 
 class UpdatingStringMorph(StringMorph):
     classID = 106
+    _fields = StringMorph._fields + ("format", "target", "getSelector",
+        "putSelector", "parameter", "floatPrecision", "growable", "stepTime")
 
 class SimpleSliderMorph(BorderedMorph):
     classID = 107
@@ -646,6 +655,9 @@ class Image(ScratchMedia):
             self.form_without_text = self.form
             self.form = self.compositeForm
 
+        if not self.size and self.form:
+            self.size = (self.form.width, self.form.height)
+
     def _encode_field(self, name, value):
         if name == 'name':
             return unicode(value)
@@ -653,7 +665,7 @@ class Image(ScratchMedia):
 
     @classmethod
     def load(cls, path):
-        """Load image file and return an Image subclass by format."""
+        """Load image file and return an Image."""
         require_pil()
 
         (_, name) = os.path.split(path)
@@ -855,7 +867,7 @@ class ScratchListMorph(BorderedMorph):
 
         self.borderColor = Color(594, 582, 582)
         self.borderWidth = 2
-        self.bounds = Rectangle([0, 0, 150, 360]) # ?
+        self.bounds = Rectangle([375, 10, 470, 125]) # ?
         self.color = Color(774, 786, 798)
 
         self.items = []
